/*!
LTC237X: 16/18/20-bit 1Msps ADC

@verbatim

The LTC237X_16/18/20 are pin-compatible, 16/18/20-bit A/D converters 
with serial I/O, and an internal reference. The ADCs typically draw only TBDmA 
from a single 5V supply. The automatic nap and sleep modes benefit power sensitive applications. 

The LTC237X_16/18/20's DC performance is outstanding with a +/-TBDLSB INL specification and 
no missing codes over temperature. The signal-to-noise ratio (SNR) for the LTC237X is typically TBDdB, with the internal reference. 


Example Code:

Read ADC input.

    adc_command = LTC237X_CH0 | LTC237X_UNIPOLAR_MODE | LTC237X_LOW_GAIN_MODE | LTC237X_NORMAL_MODE;     // Single-ended, CH0, unipolar, low gain, normal mode.
    LTC237X_read(LTC237X_CS, adc_command, &adc_code);   // Throws out last reading
    LTC237X_read(LTC237X_CS, adc_command, &adc_code);   // Obtains the current reading and stores to adc_code variable

    // Convert adc_code to voltage
    adc_voltage = LTC237X_unipolar_code_to_voltage(adc_code, LTC237X_lsb, LTC237X_offset_unipolar_code);

@endverbatim

http://www.linear.com/product/LTC237X

http://www.linear.com/product/LTC237X#demoboards

REVISION HISTORY
$Revision: 1807 $
$Date: 2013-07-29 13:06:06 -0700 (Mon, 29 Jul 2013) $

Copyright (c) 2013, Linear Technology Corp.(LTC)
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of Linear Technology Corp.

The Linear Technology Linduino is not affiliated with the official Arduino team.
However, the Linduino is only possible because of the Arduino team's commitment
to the open-source community.  Please, visit http://www.arduino.cc and
http://store.arduino.cc , and consider a purchase that will help fund their
ongoing work.
*/

/*! @file
    @ingroup LTC237X_
    Header for LTC237X: 16/18/20-bit 1Msps ADC
*/

#ifndef LTC237X_H
#define LTC237X_H

#include <SPI.h>

//! Define the SPI CS pin
#ifndef LTC237X_CS
#define LTC237X_CS QUIKEVAL_CS
#endif

//! @name LTC237X Channel Address
//! @{
// Channel Address
#define LTC237X_ADDRESS             0x00
//!@}


//! Reads the LTC237X and returns 32-bit data
//! @return void
void LTC237X_read(uint8_t cs,           //!< Chip Select Pin 
                  int32_t *ptr_adc_code    //!< Returns code read from ADC (from previous conversion)
                 );


//! Calculates the LTC237X input voltage given the binary data and lsb weight.
//! @return Floating point voltage
float LTC237X_code_to_voltage(int32_t adc_code,                   //!< Raw ADC code 
			float vref							//!< Reference voltage
			);

#endif  //  LTC237X_H


